@@ -44,7 +44,7 @@
 #'
 #' @references
 #' \itemize{
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
 #' }
 #'
 #' @examples
@@ -144,8 +144,8 @@ thin_base <- function(mat,
 #'
 #' @references
 #' \itemize{
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
-#'   \item{Robinson, David G., and John D. Storey. "subSeq: determining appropriate sequencing depth through efficient read subsampling." Bioinformatics 30, no. 23 (2014): 3424-3426.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
+#'   \item{Robinson, David G., and John D. Storey. "subSeq: determining appropriate sequencing depth through efficient read subsampling." \emph{Bioinformatics} 30, no. 23 (2014): 3424-3426. \doi{10.1093/bioinformatics/btu552}.}
 #' }
 #'
 #' @examples
@@ -215,7 +215,7 @@ thin_all <- function(mat,
 #'
 #' @references
 #' \itemize{
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
 #' }
 #'
 #' @export
@@ -299,7 +299,7 @@ thin_lib <- function(mat,
 #'
 #' @references
 #' \itemize{
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
 #' }
 #'
 #' @export
@@ -362,7 +362,7 @@ thin_gene <- function(mat,
 #' general binomial thinning approach implemented in \code{\link{thin_diff}}.
 #'
 #' The specific application of binomial thinning to the two-group model was
-#' used in Gerard and Stephens (2017) and Gerard and Stephens (2018). This is
+#' used in Gerard and Stephens (2018) and Gerard and Stephens (2021). This is
 #' a specific case of the general method described in Gerard (2020).
 #'
 #' @inheritParams thin_diff
@@ -408,15 +408,14 @@ thin_gene <- function(mat,
 #'
 #' @references
 #' \itemize{
-#'   \item{Gale, David, and Lloyd S. Shapley. "College admissions and the stability of marriage." The American Mathematical Monthly 69, no. 1 (1962): 9-15.}
-#'   \item{Gerard, David and Matthew Stephens (2017). "Unifying and generalizing methods for removing unwanted variation based on negative controls." \emph{arXiv} preprint arXiv:1705.08393.}
-#'   \item{David Gerard and Matthew Stephens (2018). "Empirical Bayes shrinkage and false discovery rate estimation, allowing for unwanted variation." \emph{Biostatistics}, doi: \href{https://doi.org/10.1093/biostatistics/kxy029}{10.1093/biostatistics/kxy029}.}
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
-#'   \item{Hansen, Ben B., and Stephanie Olsen Klopfer. "Optimal full matching and related designs via network flows." Journal of computational and Graphical Statistics 15, no. 3 (2006): 609-627.}
-#'   \item{Hornik K (2005). "A CLUE for CLUster Ensembles." Journal of Statistical Software, 14(12). doi: 10.18637/jss.v014.i12}
+#'   \item{Gale, David, and Lloyd S. Shapley. "College admissions and the stability of marriage." \emph{The American Mathematical Monthly} 69, no. 1 (1962): 9-15. \doi{10.1080/00029890.1962.11989827}.}
+#'   \item{Gerard, D., and Stephens, M. (2021). "Unifying and Generalizing Methods for Removing Unwanted Variation Based on Negative Controls." \emph{Statistica Sinica}, 31(3), 1145-1166 \doi{10.5705/ss.202018.0345}.}
+#'   \item{David Gerard and Matthew Stephens (2018). "Empirical Bayes shrinkage and false discovery rate estimation, allowing for unwanted variation." \emph{Biostatistics}, \doi{10.1093/biostatistics/kxy029}.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
+#'   \item{Hornik K (2005). "A CLUE for CLUster Ensembles." \emph{Journal of Statistical Software}, 14(12). \doi{10.18637/jss.v014.i12}. \doi{10.18637/jss.v014.i12}.}
 #'   \item{C. Papadimitriou and K. Steiglitz (1982), Combinatorial Optimization: Algorithms and Complexity. Englewood Cliffs: Prentice Hall.}
-#'   \item{Stephens, Matthew. "False discovery rates: a new deal." Biostatistics 18, no. 2 (2016): 275-294.}
-#'   \item{Wakefield, Jon. "Bayes factors for genome-wide association studies: comparison with P-values." Genetic epidemiology 33, no. 1 (2009): 79-86.}
+#'   \item{Stephens, Matthew. "False discovery rates: a new deal." \emph{Biostatistics} 18, no. 2 (2016): 275-294. \doi{10.1093/biostatistics/kxw041}.}
+#'   \item{Wakefield, Jon. "Bayes factors for genome-wide association studies: comparison with P-values." \emph{Genetic epidemiology} 33, no. 1 (2009): 79-86. \doi{10.1002/gepi.20359}.}
 #' }
 #'
 #' @examples
@@ -451,7 +450,7 @@ thin_2group <- function(mat,
                         group_prop      = 0.5,
                         corvec          = NULL,
                         alpha           = 0,
-                        permute_method  = c("optmatch", "hungarian", "marriage"),
+                        permute_method  = c("hungarian", "marriage"),
                         type            = c("thin", "mult")) {
   ## Check input --------------------------------------------------------------
   assertthat::assert_that(is.matrix(mat))
@@ -636,20 +635,12 @@ thin_2group <- function(mat,
 #'     or \code{design_fixed}. Setting this to \code{TRUE}
 #'     also changes the column-names of the corresponding coefficient matrices.
 #'     Defaults to \code{TRUE}.
-#' @param permute_method Should we use the optimal matching technique from Hansen and
-#'     Klopfer (2006) (\code{"optmatch"}), the Gale-Shapley algorithm
+#' @param permute_method Should we use the Gale-Shapley algorithm
 #'     for stable marriages (\code{"marriage"}) (Gale and Shapley, 1962)
 #'     as implemented in the matchingR package, or the Hungarian algorithm
 #'     (Papadimitriou and Steiglitz, 1982) (\code{"hungarian"})
-#'     as implemented in the clue package (Hornik, 2005)?
-#'     The \code{"optmatch"} method works really well
-#'     but does take a lot more computational time if you have, say, 1000
-#'     samples. If you use the \code{"optmatch"} option, you should note
-#'     that the optmatch package uses a super strange license:
-#'     \url{https://cran.r-project.org/package=optmatch/LICENSE}. If this
-#'     license doesn't work for you (because you are not in academia, or
-#'     because you don't believe in restrictive licenses), then
-#'     try out the \code{"hungarian"} method.
+#'     as implemented in the clue package (Hornik, 2005)? The
+#'     Hungarian method almost always works better, so is the default.
 #' @param type Should we apply binomial thinning (\code{type = "thin"}) or
 #'     just naive multiplication of the counts (\code{type = "mult"}).
 #'     You should always have this set to \code{"thin"}.
@@ -707,11 +698,10 @@ thin_2group <- function(mat,
 #'
 #' @references
 #' \itemize{
-#'   \item{Gale, David, and Lloyd S. Shapley. "College admissions and the stability of marriage." The American Mathematical Monthly 69, no. 1 (1962): 9-15.}
-#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. doi: \href{https://doi.org/10.1186/s12859-020-3450-9}{10.1186/s12859-020-3450-9}.}
-#'   \item{Hansen, Ben B., and Stephanie Olsen Klopfer. "Optimal full matching and related designs via network flows." Journal of computational and Graphical Statistics 15, no. 3 (2006): 609-627.}
-#'   \item{Hornik K (2005). "A CLUE for CLUster Ensembles." Journal of Statistical Software, 14(12). doi: 10.18637/jss.v014.i12}
-#'   \item{Leek, Jeffrey T., and John D. Storey. "A general framework for multiple testing dependence." Proceedings of the National Academy of Sciences 105, no. 48 (2008): 18718-18723.}
+#'   \item{Gale, David, and Lloyd S. Shapley. "College admissions and the stability of marriage." \emph{The American Mathematical Monthly} 69, no. 1 (1962): 9-15. \doi{10.1080/00029890.1962.11989827}.}
+#'   \item{Gerard, D (2020). "Data-based RNA-seq simulations by binomial thinning." \emph{BMC Bioinformatics}. 21(1), 206. \doi{10.1186/s12859-020-3450-9}.}
+#'   \item{Hornik K (2005). "A CLUE for CLUster Ensembles." \emph{Journal of Statistical Software}, 14(12). \doi{10.18637/jss.v014.i12}.}
+#'   \item{Leek, Jeffrey T., and John D. Storey. "A general framework for multiple testing dependence." \emph{Proceedings of the National Academy of Sciences} 105, no. 48 (2008): 18718-18723. \doi{10.1073/pnas.0808709105}.}
 #'   \item{C. Papadimitriou and K. Steiglitz (1982), Combinatorial Optimization: Algorithms and Complexity. Englewood Cliffs: Prentice Hall.}
 #' }
 #'
@@ -805,7 +795,7 @@ thin_diff <- function(mat,
                       design_obs      = NULL,
                       relative        = TRUE,
                       change_colnames = TRUE,
-                      permute_method  = c("optmatch", "hungarian", "marriage"),
+                      permute_method  = c("hungarian", "marriage"),
                       type            = c("thin", "mult")) {
   ## Check input --------------------------------------------------------------
   assertthat::assert_that(is.matrix(mat))
@@ -855,16 +845,6 @@ thin_diff <- function(mat,
   assertthat::are_equal(ncol(design_perm), ncol(coef_perm))
 
   permute_method <- match.arg(permute_method)
-  if (!is.null(target_cor) & permute_method == "optmatch" & !requireNamespace("optmatch", quietly = TRUE)) {
-    stop(paste0("\nPackage optmatch must be installed to use",
-                "`permute_method = \"optmatch\"`\n",
-                "You can install it with\n\n",
-                "install.packages(\"optmatch\")\n\n",
-                "Note that optmatch uses a strange non-standard license:\n",
-                "https://cran.r-project.org/package=optmatch/LICENSE\n"))
-  } else if (!is.null(target_cor) & permute_method == "optmatch") {
-    message_fun("optmatch")
-  }
 
   ## Permute ------------------------------------------------------------------
   if (is.null(target_cor) | ncol(design_perm) == 0) {
